# Apache License

# Copyright 2025 Text Intellect Team

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import cyrtranslit


def to_latin_serbian(text: str) -> str:
    """
    Transliterates a given text string from Serbian Cyrillic to Latin script.

    Args:
        text (str): The input text, potentially in Cyrillic.

    Returns:
        str: The transliterated text in Latin script.
    """
    # The 'sr' language code is the default, so it's not strictly necessary,
    # but it's good practice to be explicit.
    return cyrtranslit.to_latin(text, "sr")
